@@ -63,23 +63,12 @@ MainWindow::MainWindow(QWidget *parent, QString appletId) :
     XChangeProperty(QX11Info::display(), winId(), appletSettingAtom, XA_CARDINAL, 32,
             PropModeReplace, (unsigned char*)&settings, 1);
 
-#ifdef Q_WS_MAEMO_5
-    QDBusConnection conn = QDBusConnection::systemBus();
-
-    connect(ui->pbCharge, SIGNAL(valueChanged(int)), this, SLOT(ProgressBarValueSlot(int)));
-    if (!conn.connect(QString(), "/org/freedesktop/Hal/devices/bme", "org.freedesktop.Hal.Device",
-                      "PropertyModified", this, SLOT(BmePropertyModifiedSlot(QDBusMessage)))){
-        qCritical() << QString("Failed to connect to org.freedesktop.Hal.Device");
-    }
-
-    conn.connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
-                 MCE_DISPLAY_SIG, this, SLOT(DisplayStateChangedSlot(QString)));
-#endif
     ui->centralWidget->layout()->setSizeConstraint(QLayout::SetMinAndMaxSize);
 
     m_Bq27x00 = CommonStatic::Bq27x00Present(this);
     qDebug() << "Module bq27x00" << m_Bq27x00;
 
+    m_PbCharge = NULL;
     m_Timer = new QTimer(this);
     m_Timer->setInterval(1000);
     m_Timer->setSingleShot(false);
@@ -90,8 +79,19 @@ MainWindow::MainWindow(QWidget *parent, QString appletId) :
     m_LastPercentage = 0;
     m_BackgroundColor = QApplication::palette().window().color();
 
-    ProgressBarValueSlot(0);
-    ApplySettings(); 
+    ApplySettings();
+
+#ifdef Q_WS_MAEMO_5
+    QDBusConnection conn = QDBusConnection::systemBus();
+
+    if (!conn.connect(QString(), "/org/freedesktop/Hal/devices/bme", "org.freedesktop.Hal.Device",
+                      "PropertyModified", this, SLOT(BmePropertyModifiedSlot(QDBusMessage)))){
+        qCritical() << QString("Failed to connect to org.freedesktop.Hal.Device");
+    }
+
+    conn.connect(QString(), MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+                 MCE_DISPLAY_SIG, this, SLOT(DisplayStateChangedSlot(QString)));
+#endif
 }
 
 MainWindow::~MainWindow()
@@ -157,6 +157,8 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
         temperature = GetValue("/sys/class/power_supply/bq27200-0/temp");
         perc = GetValue("/sys/class/power_supply/bq27200-0/capacity");
         vcurrent = GetValue("/sys/class/power_supply/bq27200-0/voltage_now");
+        if (vcurrent > 9999)
+             vcurrent /= 1000;
     }
 
     if (temperature > 100)
@@ -181,7 +183,7 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
 
         foreach (QString line, lines){
             line = line.trimmed();
-            qDebug() << line;
+            //qDebug() << line;
 
             QStringList e = line.split("=", QString::SkipEmptyParts);
             if (e.count() > 1){
@@ -257,7 +259,8 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
             m_WasCharging = charging;
 
             if (!charging){
-                ui->pbCharge->setValue(perc * 100);
+                if (m_PbCharge)
+                    m_PbCharge->setValue(perc * 100);
                 ui->lblPerc->setText(QString("%1%").arg(QString::number(perc, 'f', 1)));
             }
 
@@ -282,7 +285,8 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
                     m_Timer->start();
             }
         }else{
-            ui->pbCharge->setValue(0);
+            if (m_PbCharge)
+                m_PbCharge->setValue(0);
             ui->lblPerc->setText(QString("%1%").arg(QString::number(0, 'f', 1)));
             ui->lblCharge->setText(QString("%1 mAh").arg(0));
             ui->lblVoltage->setText(QString("%1 mV").arg(0));
@@ -290,7 +294,8 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
         }
     }else{
         qWarning() << "Command returned" << proc->exitCode();
-        ui->pbCharge->setValue(0);
+        if (m_PbCharge)
+            m_PbCharge->setValue(0);
         ui->lblPerc->setText(QString("%1%").arg(QString::number(0, 'f', 1)));
         ui->lblCharge->setText(QString("%1 mAh").arg(0));
         ui->lblVoltage->setText(QString("%1 mV").arg(0));
@@ -302,46 +307,74 @@ void MainWindow::BmePropertyModifiedSlot(QDBusMessage)
 
 void MainWindow::ProgressBarValueSlot(int value)
 {
-    float perc = (float)value / 100.0;
-    if (!m_WasCharging)
-        ui->pbCharge->setFormat(QString("%1%").arg(QString::number(perc, 'f', 1)));
+    if (m_PbCharge){
+        float perc = (float)value / 100.0;
+        if (!m_WasCharging)
+            m_PbCharge->setFormat(QString("%1%").arg(QString::number(perc, 'f', 1)));
 
-    QString style;
+        QString style;
 
-    if (!m_WasCharging){
-        style = "QProgressBar:horizontal { \
-                   border: 0px transparent; \
-                   background: transparent; \
-                   text-align: center; \
-                 } ";
-    }else{
-        style = "QProgressBar:horizontal { \
-                   border: 0px transparent; \
-                   background: transparent; \
-                   text-align: center; \
-                   background-image: url(:/images/red.png); \
-                 } ";
+        if (!m_WasCharging){
+            style = "QProgressBar:horizontal { \
+                       border: 0px transparent; \
+                       background: transparent; \
+                       text-align: center; \
+                     } ";
+        }else{
+            style = "QProgressBar:horizontal { \
+                       border: 0px transparent; \
+                       background: transparent; \
+                       text-align: center; \
+                       background-image: url(:/images/red.png); \
+                     } ";
+        }
+
+        if (perc >= 40.0 || m_WasCharging){
+            style.append("QProgressBar::chunk:horizontal {\
+                             background-image: url(:/images/green.png); \
+                          } ");
+        }else if (perc >= 20.0){
+            style.append("QProgressBar::chunk:horizontal {\
+                             background-image: url(:/images/orange.png); \
+                          } ");
+        }else{
+            style.append("QProgressBar::chunk:horizontal {\
+                             background-image: url(:/images/red.png); \
+                          } ");
+        }
+        m_PbCharge->setStyleSheet(style);
     }
-
-    if (perc >= 40.0 || m_WasCharging){
-        style.append("QProgressBar::chunk:horizontal {\
-                         background-image: url(:/images/green.png); \
-                      } ");
-    }else if (perc >= 20.0){
-        style.append("QProgressBar::chunk:horizontal {\
-                         background-image: url(:/images/orange.png); \
-                      } ");
-    }else{
-        style.append("QProgressBar::chunk:horizontal {\
-                         background-image: url(:/images/red.png); \
-                      } ");
-    }
-    ui->pbCharge->setStyleSheet(style);
 }
 
 void MainWindow::ApplySettings()
 {
-    if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleGraphical){        
+    m_LastPercentage = 0;
+    m_LastPercentageTime = QDateTime();
+    m_LastRemainingSecs = 0;
+
+    if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleGraphical ||
+        CommonStatic::CurrentSettings->PercStyle == Settings::StyleStandard) {
+
+        if (m_PbCharge == NULL){
+            m_PbCharge = new QProgressBar(ui->frame);
+            m_PbCharge->setRange(0, 10000);
+            m_PbCharge->setValue(0);
+            m_PbCharge->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+            m_PbCharge->setTextVisible(true);
+            m_PbCharge->setContentsMargins(0,0,0,0);
+            ui->frame->layout()->addWidget(m_PbCharge);
+            connect(m_PbCharge, SIGNAL(valueChanged(int)), this, SLOT(ProgressBarValueSlot(int)));
+        }
+    }else{
+        if (m_PbCharge){
+            ui->frame->layout()->removeWidget(m_PbCharge);
+            delete m_PbCharge;
+            m_PbCharge = NULL;
+        }
+    }
+
+    if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleGraphical){
+        m_PbCharge->setFixedHeight(QWIDGETSIZE_MAX);
         QSize bkgSize(166, 98);
         bkgSize.scale(166*CommonStatic::CurrentSettings->PercScale, 98*CommonStatic::CurrentSettings->PercScale, Qt::KeepAspectRatio);
 
@@ -353,6 +386,7 @@ void MainWindow::ApplySettings()
         ui->frame->setStyleSheet("QFrame { border-image: url(:/images/battery.png); }");
         ui->frame->layout()->setContentsMargins(8, 8, 16, 8);
     }else if (CommonStatic::CurrentSettings->PercStyle == Settings::StyleStandard){
+        m_PbCharge->setFixedHeight(48);
         ui->lblPerc->setVisible(false);
         ui->frame->setVisible(true);
         ui->frame->setFixedSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
@@ -428,15 +462,17 @@ void MainWindow::SizeToFit()
 
 void MainWindow::ChargingTimerSlot()
 {
-    if (ui->pbCharge->value() == ui->pbCharge->maximum() || ui->pbCharge->value() < m_LastPercentage * 100){
-        ui->pbCharge->setValue(m_LastPercentage * 100);
-        ui->pbCharge->setFormat(QString("%1%").arg(QString::number(m_LastPercentage, 'f', 1)));
-        ui->lblPerc->setText(tr("%1% Charging").arg(QString::number(m_LastPercentage, 'f', 1)));
-    }else{
-        if (ui->pbCharge->value() + 500 > ui->pbCharge->maximum())
-            ui->pbCharge->setValue(ui->pbCharge->maximum());
-        else
-            ui->pbCharge->setValue(ui->pbCharge->value() + 500);
+    if (m_PbCharge){
+        if (m_PbCharge->value() == m_PbCharge->maximum() || m_PbCharge->value() < m_LastPercentage * 100){
+            m_PbCharge->setValue(m_LastPercentage * 100);
+            m_PbCharge->setFormat(QString("%1%").arg(QString::number(m_LastPercentage, 'f', 1)));
+            ui->lblPerc->setText(tr("%1% Charging").arg(QString::number(m_LastPercentage, 'f', 1)));
+        }else{
+            if (m_PbCharge->value() + 500 > m_PbCharge->maximum())
+                m_PbCharge->setValue(m_PbCharge->maximum());
+            else
+                m_PbCharge->setValue(m_PbCharge->value() + 500);
+        }
     }
 }
 
